pub struct FullChunkPromotion<'a> {
pub chunk: FullChunkRef<'a>,
pub pending_entities: Vec<SharedEntity>,
}Expand description
Result of promoting a proto chunk to a full chunk.
Fields
chunk: FullChunkRef<'a>Full capability initialized by this promotion.
pending_entities: Vec<SharedEntity>Entities that should be registered after the full chunk is published.